==> qtermwidget-2.0.1.tar.xz: qtermwidget-2.0.1/lib/translations/qtermwidget_nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>Konsole::Session</name>
    <message>
        <location filename="../Session.cpp" line="448"/>
        <source>Bell in session &apos;%1&apos;</source>
        <translation>Klokke i økt «%1»</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="600"/>
        <source>Session &apos;%1&apos; exited with code %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="602"/>
        <source>Session &apos;%1&apos; crashed.</source>
        <translation>Økt «%1» krasjet.</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="607"/>
        <source>Session &apos;%1&apos; exited unexpectedly.</source>
        <translation>Økt «%1» avsluttet uventet.</translation>
    </message>
</context>
<context>
    <name>Konsole::TerminalDisplay</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1278"/>
        <source>Size: XXX x XXX</source>
        <translation>Størrelse: XXX x XXX</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1290"/>
        <source>Size: %1 x %2</source>
        <translation>Størrelse: %1 x %2</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2790"/>
        <source>Paste multiline text</source>
        <translation>Lim inn flerlinjerstekst</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2791"/>
        <source>Are you sure you want to paste this text?</source>
        <translation>Er du sikker på at du vil lime inn denne teksten?</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="3261"/>
        <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Utgangssignalet ble &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;stoppet&lt;/a&gt; da Ctrl+S ble trykket.  Trykk &lt;b&gt;Ctrl+Q&lt;/b&gt; for å fortsette.&lt;/qt&gt;</translation>
    </message>
</context>
<context>
    <name>Konsole::Vt102Emulation</name>
    <message>
        <location filename="../Vt102Emulation.cpp" line="1106"/>
        <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
        <translation>Ingen tastaturoversetter er tilgjengelig. Nødvendig info for å gjøre om tastetrykk til tegn å sende terminalen mangler.</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2797"/>
        <source>Show Details...</source>
        <translation>Vis detaljer …</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ColorScheme.cpp" line="275"/>
        <location filename="../ColorScheme.cpp" line="290"/>
        <source>Un-named Color Scheme</source>
        <translation>Fargemønster uten navn</translation>
    </message>
    <message>
        <location filename="../ColorScheme.cpp" line="461"/>
        <source>Accessible Color Scheme</source>
        <translation>Fargemønster for funksjonshemmede</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="520"/>
        <source>Open Link</source>
        <translation>Åpne lenke</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="521"/>
        <source>Copy Link Address</source>
        <translation>Kopier lenkeadresse</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="525"/>
        <source>Send Email To...</source>
        <translation>Send epost til...</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="526"/>
        <source>Copy Email Address</source>
        <translation>Kopier epostadressen</translation>
    </message>
</context>
<context>
    <name>QTermWidget</name>
    <message>
        <location filename="../qtermwidget.cpp" line="465"/>
        <source>Color Scheme Error</source>
        <translation>Feil med fargemønster</translation>
    </message>
    <message>
        <location filename="../qtermwidget.cpp" line="466"/>
        <source>Cannot load color scheme: %1</source>
        <translation>Kan ikke åpne fargemønster: %1</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../SearchBar.cpp" line="39"/>
        <source>Match case</source>
        <translation>Bruk STORE og små bokstaver</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="45"/>
        <source>Regular expression</source>
        <translation>Bokstavmønstre (regex)</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="49"/>
        <source>Highlight all matches</source>
        <translation>Lys opp alle søkeresultat</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="14"/>
        <source>SearchBar</source>
        <translation>Søkelinje</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="20"/>
        <source>X</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="32"/>
        <source>Find:</source>
        <translation>Finn:</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="42"/>
        <source>&lt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="54"/>
        <source>&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="66"/>
        <source>...</source>
        <translation></translation>
    </message>
</context>
</TS>

==> qtermwidget_2.1.0.orig.tar.xz: qtermwidget-2.1.0/lib/translations/qtermwidget_nb_NO.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nb_NO">
<context>
    <name>Konsole::Session</name>
    <message>
        <location filename="../Session.cpp" line="448"/>
        <source>Bell in session &apos;%1&apos;</source>
        <translation>Klokke i økt «%1»</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="600"/>
        <source>Session &apos;%1&apos; exited with code %2.</source>
        <translation>Økt &apos;%1&apos; avsluttet med kode %2.</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="602"/>
        <source>Session &apos;%1&apos; crashed.</source>
        <translation>Økt «%1» krasjet.</translation>
    </message>
    <message>
        <location filename="../Session.cpp" line="607"/>
        <source>Session &apos;%1&apos; exited unexpectedly.</source>
        <translation>Økt «%1» avsluttet uventet.</translation>
    </message>
</context>
<context>
    <name>Konsole::TerminalDisplay</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1278"/>
        <source>Size: XXX x XXX</source>
        <translation>Størrelse: XXX x XXX</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="1290"/>
        <source>Size: %1 x %2</source>
        <translation>Størrelse: %1 x %2</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2790"/>
        <source>Paste multiline text</source>
        <translation>Lim inn flerlinjerstekst</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2791"/>
        <source>Are you sure you want to paste this text?</source>
        <translation>Er du sikker på at du vil lime inn denne teksten?</translation>
    </message>
    <message>
        <location filename="../TerminalDisplay.cpp" line="3261"/>
        <source>&lt;qt&gt;Output has been &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;suspended&lt;/a&gt; by pressing Ctrl+S.  Press &lt;b&gt;Ctrl+Q&lt;/b&gt; to resume.&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;Utgangssignalet ble &lt;a href=&quot;http://en.wikipedia.org/wiki/Flow_control&quot;&gt;stoppet&lt;/a&gt; da Ctrl+S ble trykket.  Trykk &lt;b&gt;Ctrl+Q&lt;/b&gt; for å fortsette.&lt;/qt&gt;</translation>
    </message>
</context>
<context>
    <name>Konsole::Vt102Emulation</name>
    <message>
        <location filename="../Vt102Emulation.cpp" line="1106"/>
        <source>No keyboard translator available.  The information needed to convert key presses into characters to send to the terminal is missing.</source>
        <translation>Ingen tastaturoversetter er tilgjengelig. Nødvendig info for å gjøre om tastetrykk til tegn å sende terminalen mangler.</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <location filename="../TerminalDisplay.cpp" line="2797"/>
        <source>Show Details...</source>
        <translation>Vis detaljer …</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../ColorScheme.cpp" line="275"/>
        <location filename="../ColorScheme.cpp" line="290"/>
        <source>Un-named Color Scheme</source>
        <translation>Fargemønster uten navn</translation>
    </message>
    <message>
        <location filename="../ColorScheme.cpp" line="461"/>
        <source>Accessible Color Scheme</source>
        <translation>Tilrettelagt fargeskjema</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="520"/>
        <source>Open Link</source>
        <translation>Åpne lenke</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="521"/>
        <source>Copy Link Address</source>
        <translation>Kopier lenkeadresse</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="525"/>
        <source>Send Email To...</source>
        <translation>Send epost til...</translation>
    </message>
    <message>
        <location filename="../Filter.cpp" line="526"/>
        <source>Copy Email Address</source>
        <translation>Kopier epostadressen</translation>
    </message>
</context>
<context>
    <name>QTermWidget</name>
    <message>
        <location filename="../qtermwidget.cpp" line="465"/>
        <source>Color Scheme Error</source>
        <translation>Feil med fargemønster</translation>
    </message>
    <message>
        <location filename="../qtermwidget.cpp" line="466"/>
        <source>Cannot load color scheme: %1</source>
        <translation>Kan ikke åpne fargemønster: %1</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <location filename="../SearchBar.cpp" line="39"/>
        <source>Match case</source>
        <translation>Skill mellom store/små bokstaver</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="45"/>
        <source>Regular expression</source>
        <translation>Regulært uttrykk</translation>
    </message>
    <message>
        <location filename="../SearchBar.cpp" line="49"/>
        <source>Highlight all matches</source>
        <translation>Framhev alle treff</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="14"/>
        <source>SearchBar</source>
        <translation>Søkelinje</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="20"/>
        <source>X</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="32"/>
        <source>Find:</source>
        <translation>Finn:</translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="42"/>
        <source>&lt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="54"/>
        <source>&gt;</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../SearchBar.ui" line="66"/>
        <source>...</source>
        <translation></translation>
    </message>
</context>
</TS>
